from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import String, Int, File, Boolean

Htseq_Count_V0_1_0 = CommandToolBuilder(tool="htseq_count", base_command=["htseq-count"], inputs=[ToolInput(tag="in_format", input_type=String(optional=True), prefix="--format", doc=InputDocumentation(doc="Type of <alignment_file> data. DEPRECATED: file format\nis detected automatically. This option is ignored.")), ToolInput(tag="in_order", input_type=String(optional=True), prefix="--order", doc=InputDocumentation(doc="'pos' or 'name'. Sorting order of <alignment_file>\n(default: name). Paired-end sequencing data must be\nsorted either by position or by read name, and the\nsorting order must be specified. Ignored for single-\nend data.")), ToolInput(tag="in_max_reads_in_buffer", input_type=Int(optional=True), prefix="--max-reads-in-buffer", doc=InputDocumentation(doc="When <alignment_file> is paired end sorted by\nposition, allow only so many reads to stay in memory\nuntil the mates are found (raising this number will\nuse more memory). Has no effect for single end or\npaired end sorted by name")), ToolInput(tag="in_stranded", input_type=String(optional=True), prefix="--stranded", doc=InputDocumentation(doc="Whether the data is from a strand-specific assay.\nSpecify 'yes', 'no', or 'reverse' (default: yes).\n'reverse' means 'yes' with reversed strand\ninterpretation")), ToolInput(tag="in_mina_qual", input_type=File(optional=True), prefix="--minaqual", doc=InputDocumentation(doc="Skip all reads with MAPQ alignment quality lower than\nthe given minimum value (default: 10). MAPQ is the 5th\ncolumn of a SAM/BAM file and its usage depends on the\nsoftware used to map the reads.")), ToolInput(tag="in_type", input_type=File(optional=True), prefix="--type", doc=InputDocumentation(doc="Feature type (3rd column in GTF file) to be used, all\nfeatures of other type are ignored (default, suitable\nfor Ensembl GTF files: exon)")), ToolInput(tag="in_id_attr", input_type=String(optional=True), prefix="--idattr", doc=InputDocumentation(doc="GTF attribute to be used as feature ID (default,\nsuitable for Ensembl GTF files: gene_id). All feature\nof the right type (see -t option) within the same GTF\nattribute will be added together. The typical way of\nusing this option is to count all exonic reads from\neach gene and add the exons but other uses are\npossible as well.")), ToolInput(tag="in_additional_attr", input_type=String(optional=True), prefix="--additional-attr", doc=InputDocumentation(doc="Additional feature attributes (default: none, suitable\nfor Ensembl GTF files: gene_name). Use multiple times\nfor more than one additional attribute. These\nattributes are only used as annotations in the output,\nwhile the determination of how the counts are added\ntogether is done based on option -i.")), ToolInput(tag="in_mode", input_type=String(optional=True), prefix="--mode", doc=InputDocumentation(doc="Mode to handle reads overlapping more than one feature\n(choices: union, intersection-strict, intersection-\nnonempty; default: union)")), ToolInput(tag="in_non_unique", input_type=String(optional=True), prefix="--nonunique", doc=InputDocumentation(doc="Whether and how to score reads that are not uniquely\naligned or ambiguously assigned to features (choices:\nnone, all, fraction, random; default: none)")), ToolInput(tag="in_secondary_alignments", input_type=String(optional=True), prefix="--secondary-alignments", doc=InputDocumentation(doc="Whether to score secondary alignments (0x100 flag)")), ToolInput(tag="in_supplementary_alignments", input_type=String(optional=True), prefix="--supplementary-alignments", doc=InputDocumentation(doc="Whether to score supplementary alignments (0x800 flag)")), ToolInput(tag="in_sam_out", input_type=File(optional=True), prefix="--samout", doc=InputDocumentation(doc="Write out all SAM alignment records into SAM/BAM files\n(one per input file needed), annotating each line with\nits feature assignment (as an optional field with tag\n'XF'). See the -p option to use BAM instead of SAM.")), ToolInput(tag="in_sam_out_format", input_type=String(optional=True), prefix="--samout-format", doc=InputDocumentation(doc="Format to use with the --samout option.")), ToolInput(tag="in_delimiter", input_type=String(optional=True), prefix="--delimiter", doc=InputDocumentation(doc="Column delimiter in output (default: TAB).")), ToolInput(tag="in_counts_output", input_type=File(optional=True), prefix="--counts_output", doc=InputDocumentation(doc="Filename to output the counts to instead of stdout.")), ToolInput(tag="in_append_output", input_type=File(optional=True), prefix="--append-output", doc=InputDocumentation(doc="Append counts output. This option is useful if you\nhave already creates a TSV/CSV/similar file with a\nheader for your samples (with additional columns for\nthe feature name and any additionl attributes) and\nwant to fill in the rest of the file.")), ToolInput(tag="in_n_processes", input_type=Int(optional=True), prefix="--nprocesses", doc=InputDocumentation(doc="Number of parallel CPU processes to use (default: 1).")), ToolInput(tag="in_feature_query", input_type=String(optional=True), prefix="--feature-query", doc=InputDocumentation(doc="Restrict to features descibed in this expression.\nCurrently supports a single kind of expression:\nattribute == 'one attr' to restrict the GFF to a\nsingle gene or transcript, e.g. --feature-query\n'gene_name == 'ACTB'' - notice the single quotes\naround the argument of this option and the double\nquotes around the gene name. Broader queries might\nbecome available in the future.")), ToolInput(tag="in_quiet", input_type=Boolean(optional=True), prefix="--quiet", doc=InputDocumentation(doc="Suppress progress report")), ToolInput(tag="in_sam_filenames", input_type=String(), position=0, doc=InputDocumentation(doc="Path to the SAM/BAM files containing the mapped reads.\nIf '-' is selected, read from standard input")), ToolInput(tag="in_features_filename", input_type=String(), position=1, doc=InputDocumentation(doc="Path to the GTF file containing the features"))], outputs=[ToolOutput(tag="out_counts_output", output_type=File(optional=True), selector=InputSelector(input_to_select="in_counts_output", type_hint=File()), doc=OutputDocumentation(doc="Filename to output the counts to instead of stdout.")), ToolOutput(tag="out_append_output", output_type=File(optional=True), selector=InputSelector(input_to_select="in_append_output", type_hint=File()), doc=OutputDocumentation(doc="Append counts output. This option is useful if you\nhave already creates a TSV/CSV/similar file with a\nheader for your samples (with additional columns for\nthe feature name and any additionl attributes) and\nwant to fill in the rest of the file."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Htseq_Count_V0_1_0().translate("wdl", allow_empty_container=True)

